@@ -13,7 +13,6 @@ static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/player/
 #include "misc.h"
 #include "com.h"
 #include "nat.h"
-#include "tm.h"
 #include "file.h"
 
 extern	int  add();
@@ -67,7 +66,7 @@ extern	int reco();
 extern	int repa();
 extern	int rout();
 extern	int sona();
-
+extern	int sync();
 extern	int  spy();
 extern	int tele();
 extern	int tend();
@@ -353,6 +352,7 @@ struct  comstr  player_coms[]  = {
 "strength <SECTS>", 			1,	stre,	C_MOD, NORM,
 "supply <LAND UNITS>",                  1,	supp,	C_MOD, NORM+CAP,
 "survey <COMM|VAR> <SECTS>",            0,	surv,	0, NORM+CAP,
+"sync [version|checksum|define|object <type> <which>|class <type> <which>", 0, sync, 0, VIS,
 "swapsector <SECT> <SECT>", 		0,	swaps,	C_MOD, GOD,
 "sweep <sweep-PLANES> <fighter-PLANES> <ap-SECT> <PATH|DESTINATION>",3,reco,C_MOD, NORM+MONEY+CAP,
 "telegram <NAT>",                       0,	tele,	C_MOD, NORM,
@@ -360,7 +360,7 @@ struct  comstr  player_coms[]  = {
 "territory <SECTS> <NUMBER>",		0,	terr,	C_MOD, NORM,
 "test <c|m|s|g|p|i|o|b|f|r|u> <SECT> <NUM> <PATH|DESTINATION>",1,move,0, NORM+CAP,
 "threshold <COMM> <SECTS> <THRESH>",    1,	thre,	C_MOD, NORM,
-"toggle [inform|flash|beep|coastwatch|sonar] [on|off]",          0,      togg,   C_MOD, NORM,
+"toggle [inform|flash|beep|coastwatch|sonar|sync|async] [on|off]",          0,      togg,   C_MOD, VIS,
 "torpedo <submarine-SHIPS> <target-SHIP>",3,	torp,	C_MOD, NORM+MONEY+CAP,
 "trade",                                1,	trad,	C_MOD, GOD,
 "transport <\"nuke\"|\"plane\"> <SECT|PLANES> [<NUKETYPE> <number>] <PATH|DESTINATION>",1,tran,C_MOD, NORM+CAP,
